NetworkX 3.4.2
==============

Release date: 21 October 2024

Supports Python 3.10, 3.11, 3.12, and 3.13.

NetworkX is a Python package for the creation, manipulation, and study of the
structure, dynamics, and functions of complex networks.

For more information, please visit our `website <https://networkx.org/>`_
and our :ref:`gallery of examples <examples_gallery>`.
Please send comments and questions to the `networkx-discuss mailing list
<http://groups.google.com/group/networkx-discuss>`_.

Bug Fixes
---------

- Fix docstrings of dispatchable functions (`#7679 <https://github.com/networkx/networkx/pull/7679>`_).
- Fix draw_networkx_nodes return type (`#7685 <https://github.com/networkx/networkx/pull/7685>`_).

Documentation
-------------

- Add disclaimer about LLM driven PRs (`#7683 <https://github.com/networkx/networkx/pull/7683>`_).

Maintenance
-----------

- Fix doc warnings from recently added docs (`#7682 <https://github.com/networkx/networkx/pull/7682>`_).

Contributors
------------

6 authors added to this release (alphabetically):

- Dan Schult (`@dschult <https://github.com/dschult>`_)
- Erik Welch (`@eriknw <https://github.com/eriknw>`_)
- Jarrod Millman (`@jarrodmillman <https://github.com/jarrodmillman>`_)
- Kirk Bonney (`@kbonney <https://github.com/kbonney>`_)
- Mridul Seth (`@MridulS <https://github.com/MridulS>`_)
- Ross Barnowski (`@rossbar <https://github.com/rossbar>`_)

4 reviewers added to this release (alphabetically):

- Aditi Juneja (`@Schefflera-Arboricola <https://github.com/Schefflera-Arboricola>`_)
- Dan Schult (`@dschult <https://github.com/dschult>`_)
- Jarrod Millman (`@jarrodmillman <https://github.com/jarrodmillman>`_)
- Matt Schwennesen (`@mjschwenne <https://github.com/mjschwenne>`_)

_These lists are automatically generated, and may not be complete or may contain duplicates._
